@@ -8,6 +8,7 @@ import psutil
 import json
 import requests
 from influxdb import InfluxDBClient
+from loguru import logger
 
 from monitors.monitor_set import Settings as ST
 from monitors.monitor_pid import get_process_id
@@ -138,17 +139,17 @@ def monitor(process_id):
                                         milliseconds=0)
         start_time = datetime.datetime.today()
         title = '时间' + "\t			  " + '运行状态' + "\t" + 'CPU百分比' + " " + '内存利用率' + "\t" + '虚拟内存' + "\t" + '实际使用内存' + "\t" + '网络发送包' + " " + '网络接受包' + "\n"
-        print(title)
+        logger.info(title)
         if psutil.pid_exists(process_id):
             p = psutil.Process(process_id)
             pName = p.name()
             logName = pName + "_" + str(process_id) + "_stress_monitoring_record.log"
-            print(logName + '\n')
+            logger.info(logName + '\n')
             if not os.path.exists(ST.monitor_log_path):
                 os.mkdir(ST.monitor_log_path)
             logfile = open(ST.monitor_log_path + '/' + logName, "a")
         else:
-            print("pid is not exists please enter true pid!!!")
+            logger.warning("pid is not exists please enter true pid!!!")
             return
         wTime = ST.refresh_interval
 
@@ -169,16 +170,16 @@ def monitor(process_id):
                     monitor_content = str(recTime) + "\t" + str(status) + "\t" + str(pCpu) + '%' + "\t" + str(
                         mem) + '%' + "\t" + str(
                         vmm) + "\t" + str(mm) + "\t" + str(net_sent) + "\t" + str(net_recv) + "\n"
-                    print(monitor_content)
+                    logger.info(monitor_content)
                     logfile.flush()
                     logfile.write(monitor_content)
                 except Exception as e:
-                    print('监控结束：{}'.format(e))
+                    logger.error('监控结束：{}'.format(e))
                     pass
             else:
                 monitor_content = str(datetime.datetime.today()) + "\t" + str(
                     process_id) + "  is not running!!!!!!!!!\n"
-                print(monitor_content)
+                logger.info(monitor_content)
                 logfile.flush()
                 logfile.write(monitor_content)
                 break
@@ -187,7 +188,7 @@ def monitor(process_id):
 
         logfile.close()
     except ProcessLookupError as e:
-        print('监控结束：{}'.format(e))
+        logger.info('监控结束：{}'.format(e))
         pass
 
 
@@ -197,7 +198,7 @@ def monitor_start(name):
         monitor(pid)
 
     except TypeError as E:
-        print('应用未启动 或 无此进程：{}'.format(E))
+        logger.error('应用未启动 或 无此进程：{}'.format(E))
 
 
 def get_host_ip():
@@ -291,21 +292,21 @@ def monitor_view():
                 client.write_points(network_info)
 
             except Exception as e:
-                print('End of monitoring：{}'.format(e))
+                logger.info('End of monitoring：{}'.format(e))
                 pass
 
             time.sleep(wTime)
 
     except KeyboardInterrupt:
-        print('------------------ 监控服务已停止！-----------------')
+        logger.warning('------------------ 监控服务已停止！-----------------')
         pass
 
 
 def monitor_on():
     try:
-        print('Grafana url：{}'.format(grafana_tools()))
-        print('-------------- 监控服务运行中，请勿关闭！--------------')
+        logger.info('Grafana url：{}'.format(grafana_tools()))
+        logger.info('-------------- 监控服务运行中，请勿关闭！--------------')
         monitor_view()
 
     except Exception as E:
-        print('监控服务运行异常：{}'.format(E))
+        logger.error('监控服务运行异常：{}'.format(E))
